summaryrefslogtreecommitdiffstats
path: root/kmymoney2/widgets/kmymoneydateinput.h
diff options
context:
space:
mode:
Diffstat (limited to 'kmymoney2/widgets/kmymoneydateinput.h')
-rw-r--r--kmymoney2/widgets/kmymoneydateinput.h64
1 files changed, 33 insertions, 31 deletions
diff --git a/kmymoney2/widgets/kmymoneydateinput.h b/kmymoney2/widgets/kmymoneydateinput.h
index 4561d63..0093a2d 100644
--- a/kmymoney2/widgets/kmymoneydateinput.h
+++ b/kmymoney2/widgets/kmymoneydateinput.h
@@ -20,11 +20,11 @@
// ----------------------------------------------------------------------------
// QT Includes
-#include <qwidget.h>
-#include <qlineedit.h>
-#include <qdatetime.h>
-#include <qdatetimeedit.h>
-#include <qvbox.h>
+#include <tqwidget.h>
+#include <tqlineedit.h>
+#include <tqdatetime.h>
+#include <tqdatetimeedit.h>
+#include <tqvbox.h>
// ----------------------------------------------------------------------------
// KDE Includes
@@ -43,47 +43,49 @@ class KPassivePopup;
/**
* Provided to be able to catch the focusOut events before the contents gets changed
*/
-class KMyMoneyDateEdit : public QDateEdit
+class KMyMoneyDateEdit : public TQDateEdit
{
Q_OBJECT
+ TQ_OBJECT
public:
- KMyMoneyDateEdit(const QDate& date, QWidget *parent=0, const char *name=0) : QDateEdit(date, parent, name) {}
+ KMyMoneyDateEdit(const TQDate& date, TQWidget *tqparent=0, const char *name=0) : TQDateEdit(date, tqparent, name) {}
protected:
/** reimplemented for internal reasons */
- bool event(QEvent* e);
+ bool event(TQEvent* e);
};
/**
* This class provides the general widget used for date selection
* throughout the KMyMoney project. It provides an QDateEdit widget
* which is based on an edit field with spin boxes and adds a QPushButton
* to open a KDatePicker.
*/
-class kMyMoneyDateInput : public QHBox
+class kMyMoneyDateInput : public TQHBox
{
Q_OBJECT
+ TQ_OBJECT
public:
- kMyMoneyDateInput(QWidget *parent=0, const char *name=0, Qt::AlignmentFlags flags=Qt::AlignLeft);
+ kMyMoneyDateInput(TQWidget *tqparent=0, const char *name=0, TQt::AlignmentFlags flags=TQt::AlignLeft);
~kMyMoneyDateInput();
// Replace calls to this with the new date() method
- // QDate getQDate(void) KDE_DEPRECATED;
+ // TQDate getTQDate(void) KDE_DEPRECATED;
- QDate date(void) const;
- void setDate(QDate date);
- void loadDate(const QDate& date);
+ TQDate date(void) const;
+ void setDate(TQDate date);
+ void loadDate(const TQDate& date);
void resetDate(void);
- QWidget* focusWidget(void) const;
- virtual void setRange(const QDate & min, const QDate & max) { dateEdit->setRange(min, max); }
- void markAsBadDate(bool bad = false, const QColor& = QColor());
+ TQWidget* tqfocusWidget(void) const;
+ virtual void setRange(const TQDate & min, const TQDate & max) { dateEdit->setRange(min, max); }
+ void markAsBadDate(bool bad = false, const TQColor& = TQColor());
public slots:
virtual void show(void);
signals:
- void dateChanged(const QDate& date);
+ void dateChanged(const TQDate& date);
protected:
/**
@@ -93,27 +95,27 @@ protected:
* The actual key for this to happen might be overridden through
* an i18n package. The 'T'-key is always possible.
*/
- void keyPressEvent(QKeyEvent * k);
- void resizeEvent(QResizeEvent*);
+ void keyPressEvent(TQKeyEvent * k);
+ void resizeEvent(TQResizeEvent*);
- /** To intercept events sent to focusWidget() */
- bool eventFilter(QObject *o, QEvent *e);
+ /** To intercept events sent to tqfocusWidget() */
+ bool eventFilter(TQObject *o, TQEvent *e);
protected slots:
- void slotDateChosen(QDate date);
+ void slotDateChosen(TQDate date);
void toggleDatePicker();
private slots:
- void slotDateChosenRef(const QDate& date);
+ void slotDateChosenRef(const TQDate& date);
void fixSize(void);
private:
- QDateEdit *dateEdit;
+ TQDateEdit *dateEdit;
KDatePicker *m_datePicker;
- QDate m_date; // The date !
- QDate m_prevDate;
- Qt::AlignmentFlags m_qtalignment;
- QVBox *m_dateFrame;
+ TQDate m_date; // The date !
+ TQDate m_prevDate;
+ TQt::AlignmentFlags m_qttqalignment;
+ TQVBox *m_dateFrame;
KPushButton *m_dateButton;
KPassivePopup *m_datePopup;
int m_focusDatePart;
@@ -43,47 +43,49 @@ class KPassivePopup;
/**
* This class provides the general widget used for date selection
- * throughout the KMyMoney project. It provides an QDateEdit widget
- * which is based on an edit field with spin boxes and adds a QPushButton
+ * throughout the KMyMoney project. It provides an TQDateEdit widget
+ * which is based on an edit field with spin boxes and adds a TQPushButton
* to open a KDatePicker.
*/